##########################################################################
##  This code includes an example of full data analysis using the 
##      REST statistic.  Details of the procedures can be found in: 
##      Thompson, K.L. and S. Lin.  A robust and efficient statistic
##          for detecting heterogeneous cancer samples.
##########################################################################

### Run the script 'restfunctions.R' prior to running this script
source('restfunctions.R')


#################################################################
## DATA ANALYSIS EXAMPLE
#################################################################

## Reading in Sample Data Set from .csv files
## Make sure to set the working directory
expression<-read.csv('example.csv',header=TRUE)
expr.labels<-read.csv('example_label.csv',header=TRUE)
expr.labels<-expr.labels[,1] #Make labels a row vector

## Calculate REST statistic on all the data (no permutation testing)
rest.calc<-reststat(expression,expr.labels,nu=1,perm=FALSE)

## Calculate REST statistic on all the data (with permutation testing)
N<-100 #Number of replications for the permutation testing
rest.calc.perm<-reststat(expression,expr.labels,nu=1,perm=TRUE,nreps=N)

## Perform Heterogeneity Test
heterogeneity.test.reject<-heterogeneitytest(expr=expression,labels=expr.labels)


## Recalculate REST statistic with nu=3
N<-100 #Number of replications for the permutation testing
rest.calc.perm.nu3<-reststat(expression[,heterogeneity.test.reject],expr.labels,
                             nu=3,perm=TRUE,nreps=N)
